@@ -11,9 +11,9 @@ require 'yard'
 #$LOAD_PATH.unshift(File.expand_path(File.dirname(__FILE__) + '/..'))
 
 # require our test helper so we don't have to in each individual test
-require 'test/helper'
+require './test/helper'
 
-test_files = Dir['test/base/core_ext/*_spec.rb'] + Dir['test/{base,cli,data_sources,filters,helpers,tasks}/**/test_*.rb']
+test_files = Dir['./test/base/core_ext/*_spec.rb'] + Dir['./test/{base,cli,data_sources,filters,helpers,tasks}/**/test_*.rb']
 #test_files = Dir['test/filters/test_*.rb']
 #test_files = Dir['test/filters/test_bluecloth.rb']
 test_files.each { |f| require f }
